import Vue from "vue";
import App from "./App.vue";
import "tailwindcss/tailwind.css";

new Vue({
	el: "#app",
	components: {
		App,
	},
});
